@@ -7,6 +7,8 @@ from typing import Optional, List
 class Status(Enum):
     # Stream is available for usage
     AVAILABLE = 'AVAILABLE'
+    # Stream was picked for reservation but is not reserved yet
+    LOCKED = 'LOCKED'
     # Stream in process of being reserved
     RESERVING = 'RESERVING'
     # Stream was reserved for a client that didn't connect yet
